@@ -102,8 +102,8 @@ import itertools
 from lmi.scripts import software
 from lmi.scripts.common import command
 from lmi.scripts.common import errors
-from lmi.scripts.common import formatter
 from lmi.scripts.common import get_logger
+from lmi.scripts.common.formatter import command as fcmd
 
 LOG = get_logger(__name__)
 
@@ -184,7 +184,10 @@ class FileLister(command.LmiInstanceLister):
     def execute(self, ns, package, _type=None):
         properties = [
                 ('Name'),
-                ('Type', lambda i: software.FILE_TYPES[i.FileType]),
+                ('Type', lambda i: 
+                         software.FILE_TYPES[i.FileType]
+                    if   i.FileExists
+                    else 'Missing'),
                 ('FileSize', lambda i: i.FileSize),
                 ('Passed', lambda i: len(i.FailedFlags) < 1)]
         if _type is not None:
@@ -389,7 +392,7 @@ class Verify(command.LmiLister):
 
         for_each_package_specs(ns, package_array, 'verify', _verify_identity)
         for identity, checks in failed_identity_checks:
-            yield formatter.NewTableCommand(title=identity.ElementName)
+            yield fcmd.NewTableCommand(title=identity.ElementName)
             for file_check in checks:
                 yield ( software.render_failed_flags(file_check.FailedFlags)
                       , file_check.Name)
